@@ -30,12 +30,14 @@ from jsw_nx.rubify.to_s import to_s
 # next packages
 from jsw_nx.packages.days import days
 from jsw_nx.packages.param import param
+from jsw_nx.packages.parse_cookie import parse_cookie
 from jsw_nx.packages.qs import qs
 from jsw_nx.packages.tmpl import tmpl
 from jsw_nx.packages.deep_each import deep_each
 from jsw_nx.packages.is_process_alive import is_process_alive
+from jsw_nx.packages.md5 import md5
 from jsw_nx.packages.replace_dict_all import replace_dict_all
-
+from jsw_nx.packages.uniq import uniq
 
 # next classes
 from jsw_nx.classes.date import Date
